@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 use utf8;
 use 5.008001;
 
-use version; our $VERSION = version->declare("v0.3.1");
+use version; our $VERSION = version->declare("v0.4.0");
 
 use Scalar::Util ();
 use File::Spec ();
@@ -71,6 +71,11 @@ sub add_stopwords {
     return undef;
 }
 
+sub clear_stopwords {
+    my $self = shift;
+    undef $self->{stopwords};
+}
+
 sub check_word {
     my ($self, $word) = @_;
     return 0 unless defined $word;
@@ -355,6 +360,10 @@ Loads stopwords from C<$filename_or_fh> and adds them to the on-memory dictionar
 
 Add some C<< @stopwords >> to the on memory dictionary.
 
+=item $spellunker->clear_stopwords();
+
+Crear the information of stop words.
+
 =item $spellunker->check_word($word);
 
 Check the word looks good or not.
